===========================
Arbin Electrochemical Tools
===========================


.. image:: https://img.shields.io/pypi/v/electrochem.svg
        :target: https://pypi.python.org/pypi/electrochem

.. image:: https://travis-ci.com/vince-wu/electrochem.svg?branch=master
        :target: https://travis-ci.com/vince-wu/electrochem

.. image:: https://readthedocs.org/projects/electrochem/badge/?version=latest
        :target: https://electrochem.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Reads raw electrochemical cycling data and generates useful plots and tables for battery scientists.


* Free software: MIT license
* Documentation: https://electrochem.readthedocs.io.


Features
--------

* Extracts Arbin electrochemical cycling data files (.res or .xlxs) into csv files or Pandas dataframes for easy manipulation

* Plots publication quality voltage-capacity curves 

* Calculates electrochemical properties such as operating voltage, average discharge capacity, ect. for a set of cycling data and generates summary tables

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
